@@ -1,7 +1,7 @@
-from hugegraph import PyHugeGraph
+from hugegraph import PHugeGraph
 
 if __name__ == '__main__':
-    client = PyHugeGraph("10.21.3.10", "8080", user="admin", pwd="admin", graph="hugegraph")
+    client = PHugeGraph("10.21.3.10", "8080", user="admin", pwd="admin", graph="hugegraph")
 
     """system"""
     res = client.get_graphinfo()
